[![Build Status](https://travis-ci.org/iivvoo/django_drole.png?branch=master)](https://travis-ci.org/iivvoo/django_drole)
[![Coverage Status](https://coveralls.io/repos/iivvoo/django_drole/badge.png)](https://coveralls.io/r/iivvoo/django_drole)

Django "Drole"
==============

Zope/Plone inspired role/permission authorization system for Django


